@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-python
-# Copyright(C) 2018 Fridolin Pokorny
+# Copyright(C) 2018, 2019 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,5 +28,5 @@ from .project import Project
 from .source import Source
 
 
-__version__ = "0.4.6"
-__author__ = 'Fridolin Pokorny <fridolin@redhat.com>'
+__version__ = "0.5.0"
+__author__ = "Fridolin Pokorny <fridolin@redhat.com>"
