@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-python
-# Copyright(C) 2018 Fridolin Pokorny
+# Copyright(C) 2018, 2019 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -47,11 +47,13 @@ class Source:
     warehouse = attr.ib(type=bool)
     warehouse_api_url = attr.ib(default=None, type=str)
 
+    _NORMALIZED_PACKAGE_NAME_RE = re.compile("[a-z-]+")
+
     @name.default
     def default_name(self):
         """Create a name for source based on url if not explicitly provided."""
         parsed_url = urlparse(self.url)
-        return parsed_url.netloc.replace('.', '-')
+        return parsed_url.netloc.replace(".", "-")
 
     @warehouse.default
     def warehouse_default(self):
@@ -66,19 +68,19 @@ class Source:
         if self.warehouse_api_url:
             return self.warehouse_api_url
 
-        return self.url[:-len('/simple')] + '/pypi'
+        return self.url[: -len("/simple")] + "/pypi"
 
     @classmethod
     def from_dict(cls, dict_: dict):
         """Parse source from its dictionary representation."""
         _LOGGER.debug("Parsing package source to dict representation")
         dict_ = dict(dict_)
-        warehouse_url = dict_.pop('url')
+        warehouse_url = dict_.pop("url")
         instance = cls(
-            name=dict_.pop('name'),
+            name=dict_.pop("name"),
             url=warehouse_url,
-            verify_ssl=dict_.pop('verify_ssl'),
-            warehouse=dict_.pop('warehouse', warehouse_url in config.warehouses)
+            verify_ssl=dict_.pop("verify_ssl"),
+            warehouse=dict_.pop("warehouse", warehouse_url in config.warehouses),
         )
 
         if dict_:
@@ -89,14 +91,10 @@ class Source:
     def to_dict(self, include_warehouse: bool = False) -> dict:
         """Convert source definition to its dict representation."""
         _LOGGER.debug("Converting package source to dict representation")
-        result = {
-            'url': self.url,
-            'verify_ssl': self.verify_ssl,
-            'name': self.name,
-        }
+        result = {"url": self.url, "verify_ssl": self.verify_ssl, "name": self.name}
 
         if include_warehouse:
-            result['warehouse'] = self.warehouse
+            result["warehouse"] = self.warehouse
 
         return result
 
@@ -107,7 +105,7 @@ class Source:
 
     def _warehouse_get_api_package_version_info(self, package_name: str, package_version: str) -> dict:
         """Use API of the deployed Warehouse to gather package version information."""
-        url = self.get_api_url() + f'/{package_name}/{package_version}/json'
+        url = self.get_api_url() + f"/{package_name}/{package_version}/json"
         _LOGGER.debug("Gathering package version information from Warehouse API: %r", url)
         response = requests.get(url, verify=self.verify_ssl)
         if response.status_code == 404:
@@ -119,7 +117,7 @@ class Source:
 
     def _warehouse_get_api_package_info(self, package_name: str) -> dict:
         """Use API of the deployed Warehouse to gather package information."""
-        url = self.get_api_url() + f'/{package_name}/json'
+        url = self.get_api_url() + f"/{package_name}/json"
         _LOGGER.debug("Gathering package information from Warehouse API: %r", url)
         response = requests.get(url, verify=self.verify_ssl)
         if response.status_code == 404:
@@ -132,43 +130,56 @@ class Source:
         package_info = self._warehouse_get_api_package_version_info(package_name, package_version)
 
         result = []
-        for item in package_info['urls']:
-            result.append({
-                'name': item['filename'],
-                'sha256': item['digests']['sha256']
-            })
+        for item in package_info["urls"]:
+            result.append({"name": item["filename"], "sha256": item["digests"]["sha256"]})
 
         return result
 
+    @classmethod
+    def is_normalized_python_package_name(cls, package_name: str) -> bool:
+        """Check if the given Python package name is normalized."""
+        # https://www.python.org/dev/peps/pep-0503/#normalized-names
+        return cls._NORMALIZED_PACKAGE_NAME_RE.match(package_name) is not None
+
     @lru_cache(maxsize=10)
     def get_packages(self) -> set:
         """List packages available on the source package index."""
         _LOGGER.debug(f"Discovering packages available on {self.url} (simple index name: {self.name})")
         response = requests.get(self.url, verify=self.verify_ssl)
         response.raise_for_status()
-        soup = BeautifulSoup(response.text, 'lxml')
-        links = soup.find_all('a')
+        soup = BeautifulSoup(response.text, "lxml")
+        links = soup.find_all("a")
 
         packages = set()
         for link in links:
-            package_parts = link['href'].rsplit('/', maxsplit=2)
+            package_parts = link["href"].rsplit("/", maxsplit=2)
             # According to PEP-503, package names must have trailing '/', but check this explicitly
             if not package_parts[-1]:
                 package_parts = package_parts[:-1]
-            packages.add(package_parts[-1])
+            package_name = package_parts[-1]
+
+            # Discard links to parent dirs (package name of URL does not match the text.
+            link_text = link.text
+            if link_text.endswith("/"):
+                # Link names should end with trailing / according to PEEP:
+                #   https://www.python.org/dev/peps/pep-0503/
+                link_text = link_text[:-1]
+
+            if self.is_normalized_python_package_name(package_name) and package_name == link_text:
+                packages.add(package_name)
 
         return packages
 
     @staticmethod
     def _parse_artifact_version(package_name: str, artifact_name: str) -> str:
         """Parse package version based on artifact name available on the package source index."""
-        if artifact_name.endswith('.tar.gz'):
+        if artifact_name.endswith(".tar.gz"):
             # +1 for dash delimiting package name and package version.
-            version = artifact_name[len(package_name) + 1:-len('.tar.gz')]
+            version = artifact_name[len(package_name) + 1:-len(".tar.gz")]
 
-        elif artifact_name.endswith('.whl'):
+        elif artifact_name.endswith(".whl"):
             # TODO: we will need to improve this based on PEP-0503.
-            parsed_package_name, version, _ = artifact_name.split('-', maxsplit=2)
+            parsed_package_name, version, _ = artifact_name.split("-", maxsplit=2)
             if parsed_package_name.lower() != package_name:
                 _LOGGER.warning(
                     f"It looks like package name does not match the one parsed from artifact when "
@@ -200,10 +211,11 @@ class Source:
             return self._simple_repository_list_versions(package_name)
 
         package_info = self._warehouse_get_api_package_info(package_name)
-        return list(package_info['releases'].keys())
+        return list(package_info["releases"].keys())
 
-    def get_latest_package_version(self, package_name: str,
-                                   graceful: bool = False) -> typing.Optional[semver.base.Version]:
+    def get_latest_package_version(
+        self, package_name: str, graceful: bool = False
+    ) -> typing.Optional[semver.base.Version]:
         """Get the latest version for the given package."""
         try:
             all_versions = self.get_package_versions(package_name)
@@ -231,35 +243,35 @@ class Source:
 
     def _simple_repository_list_artifacts(self, package_name: str) -> list:
         """Parse simple repository package listing (HTML) and return artifacts present there."""
-        url = self.url + '/' + package_name
+        url = self.url + "/" + package_name
 
         _LOGGER.debug(f"Discovering package %r artifacts from %r", package_name, url)
         response = requests.get(url, verify=self.verify_ssl)
         if response.status_code == 404:
             raise NotFound(f"Package {package_name} is not present on index {self.url} (index {self.name})")
         response.raise_for_status()
-        soup = BeautifulSoup(response.text, 'lxml')
+        soup = BeautifulSoup(response.text, "lxml")
 
-        links = soup.find_all('a')
+        links = soup.find_all("a")
         artifacts = []
         for link in links:
-            artifact_name = str(link['href']).rsplit('/', maxsplit=1)
+            artifact_name = str(link["href"]).rsplit("/", maxsplit=1)
             if len(artifact_name) == 2:
                 # If full URL provided by index.
                 artifact_name = artifact_name[1]
             else:
                 artifact_name = artifact_name[0]
 
-            artifact_parts = artifact_name.rsplit('#', maxsplit=1)
+            artifact_parts = artifact_name.rsplit("#", maxsplit=1)
             if len(artifact_parts) == 2:
                 artifact_name = artifact_parts[0]
 
-            if not artifact_name.endswith(('.tar.gz', '.whl')):
-                _LOGGER.debug("Link does not look like a package for %r: %r", package_name, link['href'])
+            if not artifact_name.endswith((".tar.gz", ".whl")):
+                _LOGGER.debug("Link does not look like a package for %r: %r", package_name, link["href"])
                 continue
 
-            artifact_url = link['href']
-            if not artifact_url.startswith(('http://', 'https://')):
+            artifact_url = link["href"]
+            if not artifact_url.startswith(("http://", "https://")):
                 artifact_url = url + f"/{artifact_name}"
 
             artifacts.append((artifact_name, artifact_url))
@@ -275,14 +287,18 @@ class Source:
                 # TODO: this logic has to be improved as package version can be a suffix of another package version:
                 #   mypackage-1.0.whl, mypackage-1.0.0.whl, ...
                 # This will require parsing based on PEP or some better logic.
-                _LOGGER.debug("Skipping artifact %r as it does not match required version %r for package %r",
-                              artifact_name, package_version, package_name)
+                _LOGGER.debug(
+                    "Skipping artifact %r as it does not match required version %r for package %r",
+                    artifact_name,
+                    package_version,
+                    package_name,
+                )
                 continue
 
-            url_parts = artifact_url.rsplit('#', maxsplit=1)
-            if len(url_parts) == 2 and url_parts[1].startswith('sha256='):
+            url_parts = artifact_url.rsplit("#", maxsplit=1)
+            if len(url_parts) == 2 and url_parts[1].startswith("sha256="):
                 _LOGGER.debug("Using SHA256 stated in URL: %r", url_parts[1])
-                yield artifact_name, url_parts[1][len('sha256='):]
+                yield artifact_name, url_parts[1][len("sha256="):]
                 continue
 
             _LOGGER.debug("Downloading artifact from url %r", artifact_url)
@@ -313,8 +329,6 @@ class Source:
             return self._warehouse_get_package_hashes(package_name, package_version)
 
         return [
-            {
-                'name': name,
-                'sha256': digest
-            } for name, digest in self._download_artifacts_sha(package_name, package_version)
+            {"name": name, "sha256": digest}
+            for name, digest in self._download_artifacts_sha(package_name, package_version)
         ]
